summaryrefslogtreecommitdiffstats
path: root/kttsd/libkttsd
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/libkttsd')
-rw-r--r--kttsd/libkttsd/filterconf.cpp8
-rw-r--r--kttsd/libkttsd/filterconf.h8
-rw-r--r--kttsd/libkttsd/filterproc.cpp2
-rw-r--r--kttsd/libkttsd/filterproc.h4
-rw-r--r--kttsd/libkttsd/notify.cpp4
-rw-r--r--kttsd/libkttsd/pluginconf.cpp8
-rw-r--r--kttsd/libkttsd/pluginconf.h8
-rw-r--r--kttsd/libkttsd/pluginproc.cpp2
-rw-r--r--kttsd/libkttsd/pluginproc.h4
-rw-r--r--kttsd/libkttsd/selecttalkerdlg.cpp2
10 files changed, 25 insertions, 25 deletions
diff --git a/kttsd/libkttsd/filterproc.cpp b/kttsd/libkttsd/filterproc.cpp
index 2759a4b..0847879 100644
--- a/kttsd/libkttsd/filterproc.cpp
+++ b/kttsd/libkttsd/filterproc.cpp
@@ -54,7 +54,7 @@ KttsFilterProc::~KttsFilterProc()
* Note: The parameters are for reading from kttsdrc file. Plugins may wish to maintain
* separate configuration files of their own.
*/
-bool KttsFilterProc::init(KConfig* /*config*/, const TQString& /*configGroup*/){
+bool KttsFilterProc::init(TDEConfig* /*config*/, const TQString& /*configGroup*/){
// kdDebug() << "PlugInProc::init: Running" << endl;
return false;
}
diff --git a/kttsd/libkttsd/filterproc.h b/kttsd/libkttsd/filterproc.h
index 46ec6be..73b1566 100644
--- a/kttsd/libkttsd/filterproc.h
+++ b/kttsd/libkttsd/filterproc.h
@@ -34,7 +34,7 @@
#include "kdeexportfix.h"
class TalkerCode;
-class KConfig;
+class TDEConfig;
class KDE_EXPORT KttsFilterProc : virtual public TQObject
{
@@ -68,7 +68,7 @@ public:
* Note: The parameters are for reading from kttsdrc file. Plugins may wish to maintain
* separate configuration files of their own.
*/
- virtual bool init(KConfig *config, const TQString &configGroup);
+ virtual bool init(TDEConfig *config, const TQString &configGroup);
/**
* Returns True if this filter is a Sentence Boundary Detector.
diff --git a/kttsd/libkttsd/notify.cpp b/kttsd/libkttsd/notify.cpp
index bd2fbd1..4e25693 100644
--- a/kttsd/libkttsd/notify.cpp
+++ b/kttsd/libkttsd/notify.cpp
@@ -149,7 +149,7 @@ static void notifypresent_init()
/*static*/ TQString NotifyEvent::getEventSrcName(const TQString& eventSrc, TQString& iconName)
{
TQString configFilename = eventSrc + TQString::fromLatin1( "/eventsrc" );
- KConfig* config = new KConfig( configFilename, true, false, "data" );
+ TDEConfig* config = new TDEConfig( configFilename, true, false, "data" );
config->setGroup( TQString::fromLatin1( "!Global!" ) );
TQString appDesc = config->readEntry( "Comment", i18n("No description available") );
iconName = config->readEntry( "IconName" );
@@ -164,7 +164,7 @@ static void notifypresent_init()
{
TQString eventName;
TQString configFilename = eventSrc + TQString::fromLatin1( "/eventsrc" );
- KConfig* config = new KConfig( configFilename, true, false, "data" );
+ TDEConfig* config = new TDEConfig( configFilename, true, false, "data" );
if ( config->hasGroup( event ) )
{
config->setGroup( event );
diff --git a/kttsd/libkttsd/pluginproc.cpp b/kttsd/libkttsd/pluginproc.cpp
index 53ab839..d50d668 100644
--- a/kttsd/libkttsd/pluginproc.cpp
+++ b/kttsd/libkttsd/pluginproc.cpp
@@ -45,7 +45,7 @@ PlugInProc::~PlugInProc(){
/**
* Initializate the speech plugin.
*/
-bool PlugInProc::init(KConfig* /*config*/, const TQString& /*configGroup*/){
+bool PlugInProc::init(TDEConfig* /*config*/, const TQString& /*configGroup*/){
// kdDebug() << "PlugInProc::init: Running" << endl;
return false;
}
diff --git a/kttsd/libkttsd/selecttalkerdlg.cpp b/kttsd/libkttsd/selecttalkerdlg.cpp
index 4c73290..0091215 100644
--- a/kttsd/libkttsd/selecttalkerdlg.cpp
+++ b/kttsd/libkttsd/selecttalkerdlg.cpp
@@ -317,7 +317,7 @@ void SelectTalkerDlg::loadTalkers(bool /*runningTalkers*/)
KListView* lv = m_widget->talkersListView;
lv->clear();
TQListViewItem* item;
- KConfig* config = new KConfig("kttsdrc");
+ TDEConfig* config = new TDEConfig("kttsdrc");
config->setGroup("General");
TQStringList talkerIDsList = config->readListEntry("TalkerIDs", ',');
if (!talkerIDsList.isEmpty())
diff --git a/kttsd/libkttsd/filterconf.cpp b/kttsd/libkttsd/filterconf.cpp
index b4f8a1d..00e42e1 100644
--- a/kttsd/libkttsd/filterconf.cpp
+++ b/kttsd/libkttsd/filterconf.cpp
@@ -66,11 +66,11 @@ KttsFilterConf::~KttsFilterConf(){
* loaded, so it not necessary to call it in your constructor.
* The plugin should read its configuration from the specified group
* in the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
*/
-void KttsFilterConf::load(KConfig* /*config*/, const TQString& /*configGroup*/){
+void KttsFilterConf::load(TDEConfig* /*config*/, const TQString& /*configGroup*/){
// kdDebug() << "KttsFilterConf::load: Running" << endl;
}
@@ -80,11 +80,11 @@ void KttsFilterConf::load(KConfig* /*config*/, const TQString& /*configGroup*/){
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
*/
-void KttsFilterConf::save(KConfig* /*config*/, const TQString& /*configGroup*/){
+void KttsFilterConf::save(TDEConfig* /*config*/, const TQString& /*configGroup*/){
// kdDebug() << "KttsFilterConf::save: Running" << endl;
}
@@ -66,11 +66,11 @@ KttsFilterConf::~KttsFilterConf(){
* The plugin should read its configuration from the specified group
* in the specified config file.
-* @param config Pointer to a KConfig object.
+* @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
@@ -80,11 +80,11 @@ void KttsFilterConf::load(KConfig* /*config*/, const TQString& /*configGroup*/){
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
-* @param config Pointer to a KConfig object.
+* @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
diff --git a/kttsd/libkttsd/filterconf.h b/kttsd/libkttsd/filterconf.h
index 9b52c31..606813c 100644
--- a/kttsd/libkttsd/filterconf.h
+++ b/kttsd/libkttsd/filterconf.h
@@ -58,7 +58,7 @@ class KDE_EXPORT KttsFilterConf : public TQWidget{
* loaded, so it not necessary to call it in your constructor.
* The plugin should read its configuration from the specified group
* in the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
*
@@ -67,7 +67,7 @@ class KDE_EXPORT KttsFilterConf : public TQWidget{
* any instance-specific parameters to load, but it may still wish
* to load parameters that apply to all instances of the plugin.
*/
- virtual void load(KConfig *config, const TQString &configGroup);
+ virtual void load(TDEConfig *config, const TQString &configGroup);
/**
* This function gets called when the user wants to save the settings in
@@ -75,11 +75,11 @@ class KDE_EXPORT KttsFilterConf : public TQWidget{
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
*/
- virtual void save(KConfig *config, const TQString &configGroup);
+ virtual void save(TDEConfig *config, const TQString &configGroup);
/**
* This function is called to set the settings in the module to sensible
@@ -58,7 +58,7 @@ class KDE_EXPORT KttsFilterConf : public TQWidget{
* The plugin should read its configuration from the specified group
* in the specified config file.
- * @param config Pointer to a KConfig object.
+ * @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
@@ -75,11 +75,11 @@ class KDE_EXPORT KttsFilterConf : public TQWidget{
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
- * @param config Pointer to a KConfig object.
+ * @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
diff --git a/kttsd/libkttsd/pluginconf.cpp b/kttsd/libkttsd/pluginconf.cpp
index 0674057..b076729 100644
--- a/kttsd/libkttsd/pluginconf.cpp
+++ b/kttsd/libkttsd/pluginconf.cpp
@@ -62,11 +62,11 @@ PlugInConf::~PlugInConf(){
* loaded, so it not necessary to call it in your constructor.
* The plugin should read its configuration from the specified group
* in the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
*/
-void PlugInConf::load(KConfig* /*config*/, const TQString& /*configGroup*/){
+void PlugInConf::load(TDEConfig* /*config*/, const TQString& /*configGroup*/){
kdDebug() << "PlugInConf::load: Running" << endl;
}
@@ -76,11 +76,11 @@ void PlugInConf::load(KConfig* /*config*/, const TQString& /*configGroup*/){
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
*/
-void PlugInConf::save(KConfig* /*config*/, const TQString& /*configGroup*/){
+void PlugInConf::save(TDEConfig* /*config*/, const TQString& /*configGroup*/){
kdDebug() << "PlugInConf::save: Running" << endl;
}
@@ -62,11 +62,11 @@ PlugInConf::~PlugInConf(){
* The plugin should read its configuration from the specified group
* in the specified config file.
-* @param config Pointer to a KConfig object.
+* @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
@@ -76,11 +76,11 @@ void PlugInConf::load(KConfig* /*config*/, const TQString& /*configGroup*/){
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
-* @param config Pointer to a KConfig object.
+* @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
diff --git a/kttsd/libkttsd/pluginconf.h b/kttsd/libkttsd/pluginconf.h
index 542d8cd..37081df 100644
--- a/kttsd/libkttsd/pluginconf.h
+++ b/kttsd/libkttsd/pluginconf.h
@@ -231,7 +231,7 @@ class KDE_EXPORT PlugInConf : public TQWidget{
* loaded, so it not necessary to call it in your constructor.
* The plugin should read its configuration from the specified group
* in the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
*
@@ -242,7 +242,7 @@ class KDE_EXPORT PlugInConf : public TQWidget{
*
* @see loadandsavemethods
*/
- virtual void load(KConfig *config, const TQString &configGroup);
+ virtual void load(TDEConfig *config, const TQString &configGroup);
/**
* This function gets called when the user wants to save the settings in
@@ -250,7 +250,7 @@ class KDE_EXPORT PlugInConf : public TQWidget{
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
* @param config Pointer to a KConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
*
@@ -258,7 +258,7 @@ class KDE_EXPORT PlugInConf : public TQWidget{
* it is not necessary to save the language code, unless your plugin needs it in
* order to synthesize speech.
*/
- virtual void save(KConfig *config, const TQString &configGroup);
+ virtual void save(TDEConfig *config, const TQString &configGroup);
/**
* This function is called to set the settings in the module to sensible
@@ -231,7 +231,7 @@ class KDE_EXPORT PlugInConf : public TQWidget{
* The plugin should read its configuration from the specified group
* in the specified config file.
- * @param config Pointer to a KConfig object.
+ * @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* loading your configuration.
@@ -250,7 +250,7 @@ class KDE_EXPORT PlugInConf : public TQWidget{
* or "Ok". The plugin should save its configuration in the specified
* group of the specified config file.
- * @param config Pointer to a KConfig object.
+ * @param config Pointer to a TDEConfig object.
* @param configGroup Call config->setGroup with this argument before
* saving your configuration.
diff --git a/kttsd/libkttsd/pluginproc.h b/kttsd/libkttsd/pluginproc.h
index 0467302..f856193 100644
--- a/kttsd/libkttsd/pluginproc.h
+++ b/kttsd/libkttsd/pluginproc.h
@@ -119,7 +119,7 @@
*
* Since the KDE library is not available from the @ref sayText and @ref synthText methods,
* it is best if the plugin reads configuration settings in the @ref init method.
* The KConfig object is passed as an argument to @ref init .
*
* If the synthesis engine requires a long initialization time (more than a second),
* it is best if the plugin loads the speech engine from the @ref init method.
@@ -264,7 +264,7 @@ class KDE_EXPORT PlugInProc : virtual public TQObject{
config->setGroup(configGroup);
@endverbatim
*/
- virtual bool init(KConfig *config, const TQString &configGroup);
+ virtual bool init(TDEConfig *config, const TQString &configGroup);
/**
* Say a text. Synthesize and audibilize it.
@@ -119,7 +119,7 @@
* Since the KDE library is not available from the @ref sayText and @ref synthText methods,
* it is best if the plugin reads configuration settings in the @ref init method.
-* The KConfig object is passed as an argument to @ref init .
+* The TDEConfig object is passed as an argument to @ref init .
*
* If the synthesis engine requires a long initialization time (more than a second),